package core.notevault.sync;
import android.content.Context;
import android.util.Log;
import androidx.annotation.NonNull;
import androidx.work.Worker;
import androidx.work.WorkerParameters;
import core.notevault.data.Concert;
import core.notevault.data.MusicDatabase;
import core.notevault.data.MusicNoteDAO;
import core.notevault.data.sync.SyncAction;
import core.notevault.data.sync.SyncObject;
import core.notevault.data.sync.SyncResponse;
import core.notevault.data.sync.SyncStatus;
import core.notevault.sync.synchronisation.*;
import core.notevault.sync.synchronisation.songs.SongSyncWorker;
import core.notevault.sync.synchronisation.songs.creation.SongCreationBatchResponse;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

import java.io.IOException;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.stream.Collectors;

public class SyncWorker extends Worker{
    private SongSyncWorker songSyncWorker;
    public SyncWorker(@NonNull Context context, @NonNull WorkerParameters workerParams) {
        super(context, workerParams);
        SyncService syncService = ApiClient.getRetrofitInstance(context).create(SyncService.class);
        MusicDatabase musicDatabase = MusicDatabase.getDatabase(context);
        this.songSyncWorker = new SongSyncWorker(syncService, musicDatabase.musicNoteDao(), context);
    }

    @NonNull
    @Override
    public Result doWork() {
        try {
            songSyncWorker.syncSongCreations();
            return Result.success();
        } catch (Exception e) {
            return Result.failure();
        }
    }


}
