package core.notevault.ui.login;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.DialogFragment;
import core.notevault.R;
import core.notevault.sync.APICallback;
import core.notevault.sync.auth.AuthRepository;
import core.notevault.sync.auth.LoginCallback;
import retrofit2.Call;
import retrofit2.Callback;

public class LoginDialogFragment extends DialogFragment {
    private APICallback loginCallback;
    private APICallback registerCallback;

    private boolean isLoginMode = true; // Default mode

    @Override
    public void onAttach(Context context) {
        super.onAttach(context);
        if (loginCallback == null || registerCallback == null) {
            throw new IllegalStateException("LoginDialogFragment must be created using newInstance()");
        }
    }

    public static LoginDialogFragment newInstance(APICallback loginCallback, APICallback registerCallback) {
        LoginDialogFragment fragment = new LoginDialogFragment();
        fragment.loginCallback = loginCallback;
        fragment.registerCallback = registerCallback;
        return fragment;
    }

    @NonNull
    @Override
    public Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        /*return new AlertDialog.Builder(requireContext())
                .setView(loginView)
                .setPositiveButton("Speichern", (dialog, which) -> {
                    String username = usernameInput.getText().toString();
                    String password = passwordInput.getText().toString();

                    authRepository.performLogin(username, password, loginCallback);
                } )
                .setNegativeButton("Abbrechen", (dialog, which) -> {} )
                .create();*/

        AlertDialog.Builder builder = new AlertDialog.Builder(requireContext());
        LayoutInflater inflater = requireActivity().getLayoutInflater();
        View view = inflater.inflate(R.layout.fragment_login_dialog, null);

        TextView textViewTitle = view.findViewById(R.id.textViewTitle);
        EditText editTextUsername = view.findViewById(R.id.editTextUsername);
        EditText editTextEmail = view.findViewById(R.id.editTextEmail);
        EditText editTextPassword = view.findViewById(R.id.editTextPassword);
        Button buttonAction = view.findViewById(R.id.buttonAction);
        TextView textViewSwitch = view.findViewById(R.id.textViewSwitch);

        // Handle action button click
        buttonAction.setOnClickListener(v -> {
            if (isLoginMode) {
                // Handle login logic
                String email = editTextEmail.getText().toString();
                String password = editTextPassword.getText().toString();
                AuthRepository authRepository = new AuthRepository(this.getContext());
                authRepository.performLogin(email, password, loginCallback);
            } else {
                // Handle registration logic
                String email = editTextEmail.getText().toString();
                String password = editTextPassword.getText().toString();
                String username = editTextUsername.getText().toString();
                AuthRepository authRepository = new AuthRepository(this.getContext());
                authRepository.performRegistration(email, username, password, registerCallback);
            }
        });

        // Toggle between Login and Registration
        textViewSwitch.setOnClickListener(v -> {
            isLoginMode = !isLoginMode;
            textViewTitle.setText(isLoginMode ? "Login" : "Register");
            editTextUsername.setVisibility(isLoginMode ? View.GONE : View.VISIBLE);
            buttonAction.setText(isLoginMode ? "Login" : "Register");
            textViewSwitch.setText(isLoginMode ? "Don't have an account? Register" : "Already have an account? Login");
        });

        builder.setView(view);
        return builder.create();
    }


}
