package core.notevault.ui.metadatadialog;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.DialogFragment;
import core.notevault.R;
import core.notevault.data.MusicNote;
import core.notevault.data.sync.SyncStatus;

public class SongEditDialog extends DialogFragment {

    private MusicNote song;
    private SongEditorListener songEditorListener;

    public interface SongEditorListener {
        void onSongEdited(MusicNote updatedSong);
    }

    @NonNull
    @Override
    public Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        LayoutInflater inflater = requireActivity().getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.song_metadata_edit_dialog, null); // Ersetze 'your_dialog_layout' durch deinen Dateinamen

        EditText title_input = dialogView.findViewById(R.id.title_input);
        title_input.setText(song.getTitle());
        EditText composer_input = dialogView.findViewById(R.id.composer_input);
        composer_input.setText(song.getComposer());
        EditText year_input = dialogView.findViewById(R.id.year_input);
        year_input.setText(String.valueOf(song.getYear()));
        EditText genre_input = dialogView.findViewById(R.id.genre_input);
        genre_input.setText(song.getGenre());

        return new AlertDialog.Builder(requireContext())
                .setView(dialogView)
                .setPositiveButton("Speichern", (dialog, which) -> {
                    String title = title_input.getText().toString();
                    String composer = composer_input.getText().toString();

                    String year_string = year_input.getText().toString();
                    int year = 0;
                    if(!year_string.isEmpty()) {
                        year = Integer.parseInt(year_input.getText().toString());
                    }

                    String genre = genre_input.getText().toString();

                    song.setTitle(title);
                    song.setComposer(composer);
                    song.setGenre(genre);
                    song.setYear(year);
                    song.setSyncStatus(SyncStatus.MODIFIED);

                    songEditorListener.onSongEdited(song);
                } )
                .setNegativeButton("Abbrechen", (dialog, which) -> {} )
                .create();
    }

    public MusicNote getSong() {
        return song;
    }

    public void setSong(MusicNote song) {
        this.song = song;
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        if (context instanceof MetaDataDialog.OnMetadataListener) {
            songEditorListener = (SongEditorListener) context;
        } else {
            throw new RuntimeException(context.toString()
                    + " must implement OnMetadataListener");
        }
    }

    public static String TAG = "SONGEDITDIALOG";
}
